////////////////////////////////////////////////////////////////////////
//
// Author:     Xilinx
// Date:       July 11th 2007 $
// Design:     Virtex-5 System Monitor Verilog example instantiation 
//
// System Monitor instantiation by hand using the Language Template
//  
////////////////////////////////////////////////////////////////////////

`timescale 1ns / 1 ps

module v5_sysmon 
(

   // Inputs
   clk,
   
   // Outputs
   Vccaux,
   busy,
   alarm
      
);
  
   //Inputs
   input   clk;
   
   //Output
   output [9:0] Vccaux;
   output  busy;
   output  alarm;
   
      
   wire [15:0] dobus;  
   wire [4:0] channel;
   wire [2:0] alm;
   wire eos;
	
	
	// bring out 10-bit (MSBs) version of DO bus
   
   assign Vccaux = dobus[15:6];
   assign alarm = alm[2];
      
   
	// SYSMON: System Monitor
   // Virtex-5
   // Xilinx HDL Language Template, version 9.2.1i

   SYSMON #(
      .INIT_40(16'h0), // Configuration register 0
      .INIT_41(16'h20C7), // Configuration register 1
      .INIT_42(16'h0A00), // Configuration register 2
      .INIT_43(16'h0), // Test register 0
      .INIT_44(16'h0), // Test register 1
      .INIT_45(16'h0), // Test register 2
      .INIT_46(16'h0), // Test register 3
      .INIT_47(16'h0), // Test register 4
      .INIT_48(16'h0401), // Sequence register 0
      .INIT_49(16'h0), // Sequence register 1
      .INIT_4A(16'h0), // Sequence register 2
      .INIT_4B(16'h0), // Sequence register 3
      .INIT_4C(16'h0), // Sequence register 4
      .INIT_4D(16'h0), // Sequence register 5
      .INIT_4E(16'h0), // Sequence register 6
      .INIT_4F(16'h0), // Sequence register 7
      .INIT_50(16'h0), // Alarm limit register 0
      .INIT_51(16'h0), // Alarm limit register 1
      .INIT_52(16'hE000), // Alarm limit register 2
      .INIT_53(16'h0), // Alarm limit register 3
      .INIT_54(16'h0), // Alarm limit register 4
      .INIT_55(16'h0), // Alarm limit register 5
      .INIT_56(16'hCAAA), // Alarm limit register 6
      .INIT_57(16'h0), // Alarm limit register 7
      .SIM_MONITOR_FILE("vccaux_alarm.txt") // Simulation analog entry file
		
   ) my_sysmon (
        .ALM(alm),           		// 3-bit output for temp, Vccint and Vccaux
        .BUSY(busy),         		// 1-bit output ADC busy signal
        .CHANNEL(channel),   		// 5-bit output channel selection
        .DO(dobus),            	// 16-bit output data bus for dynamic reconfig port
        
        
        .EOS(eos),           		// 1-bit output end of sequence
        
        .DADDR({2'b0, channel}),	// 7-bit input address bus for dynamic reconfig port
        .DCLK(clk),         		// 1-bit input clock for dynamic reconfig port
        .DEN(eos),           		// 1-bit input enable for dynamic reconfig port
        
        .DWE(1'b0),           	// 1-bit input write enable for dynamic reconfig port
        .RESET(1'b0)       		// 1-bit input active high reset
        
   );
   
       
   
endmodule


